#
# spec file for package python-nocaselist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-nocaselist
Version:        2.0.3
Release:        1.3
Summary:        A case-insensitive list for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/pywbem/nocaselist
Source:         https://files.pythonhosted.org/packages/source/n/nocaselist/nocaselist-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-typing-extensions
BuildArch:      noarch
%python_subpackages

%description
Class `NocaseList`_ is a case-insensitive list that preserves the lexical case
of its items.

%prep
%setup -q -n nocaselist-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/nocaselist
%{python_sitelib}/nocaselist-%{version}.dist-info

%changelog
* Thu Nov  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.3:
  * Fixed safety issues up to 2024-08-18.
  * Fixed new issues from pylint 3.2.
  * Fixed missing Python 3.12 in Trove classifiers.
  * Increased vrsions of GitHub Actions plugins used, to eliminate
    warnings about node v16.
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * support python 3.12
  * cleanup pip backtracking
  * Fix content type of pacakge description
  * use f-streings
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Installation of this package using “setup.py” is no longer
    supported. Use “pip” instead.
  * Test: Fixed issues resulting from removal of support for
    pytest.warns(None) in pytest version 8
  * Fixed safety issues up to 2024-05-04
* Fri Dec  1 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * typing hints
  * Fixed coveralls issues with KeyError and HTTP 422
    Unprocessable Entity.
  * Added support for passing slices to '__setitem__()' and
    '__delitem__()'. Expanded the testcases accordingly.
  * Fixed incorrect error handling when passing objects of
    unsupported types to the right hand operand of the rich
    comparison methods of NocaseList. This previously caused
    AttributeError "'list' object has no attribute 'lower'" and
    TypeError "'int' object is not iterable" to be raised which was
    confusing. This is now handled by returning 'NotImplemented'
    from these methods as recommended by Python, causing TypeError
    with a proper message to be raised by Python.#
  * Resurrected support for byte strings as list values in the
    default implementation of the casefold method. The list can now
    contains unicode strings and byte strings.
  * Added type hints and type checking with MyPy (issue #96).
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Mitigated coveralls issue with HTTP status 422
  * Add python 3.9 support
  * Test suite cleanups, Pylint 2.10 fixes
  * Python 3.10 support
* Mon Feb  1 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * Migrated from Travis and Appveyor to GitHub Actions. This required changes
    in several areas including dependent packages used for testing and
    coverage. This did not cause any changes on dependent packages used for the
    installation of the package.
* Tue Oct 13 2020 Benjamin Greiner <code@bnavigator.de>
- initial specfile 1.0.3
